import unittest
from color_mapper import value_to_color

class TestColorMapper(unittest.TestCase):

    def test_value_to_color(self):
        values = [10, 20, 30, 40, 50, 60, 70, 80, 90, 100]
        color_bases = ['blue', 'yellow', 'red']
        result = value_to_color(values, color_bases)
        self.assertEqual(len(result), len(values))
        for item in result:
            self.assertIn('value', item)
            self.assertIn('color', item)
            self.assertTrue(item['color'].startswith('#'))

if __name__ == '__main__':
    unittest.main()



import matplotlib.pyplot as plt
import matplotlib.colors as mcolors

def get_color_interpolator(colors):
    """Create a color interpolator from the provided base colors."""
    cmap = mcolors.LinearSegmentedColormap.from_list("custom_cmap", colors)
    def interpolator(value):
        return cmap(value)
    return interpolator

def rgb_to_hex(rgb):
    """Convert RGB color to hex format."""
    return '#{:02x}{:02x}{:02x}'.format(int(rgb[0]*255), int(rgb[1]*255), int(rgb[2]*255))



from .normalizer import normalize
from .interpolator import get_color_interpolator, rgb_to_hex

def value_to_color(values, color_bases):
    """Normalize the values and map them to a color gradient based on provided color bases."""
    min_value = min(values)
    max_value = max(values)
    interpolator = get_color_interpolator(color_bases)

    color_data = []
    for value in values:
        normalized_value = normalize(value, min_value, max_value)
        rgb_color = interpolator(normalized_value)
        hex_color = rgb_to_hex(rgb_color[:3])  # Convert only the RGB part, ignore alpha
        color_data.append({
            'value': value,
            'color': hex_color
        })

    return color_data
